@@ -28,16 +28,29 @@ update; after $delay
 update; after $delay
 
 # This time the text is repeated: "Hello", approx. 5mm space, "Hello".
-.c it st -space 5m
+.c itemco st -space 5m
 update; after $delay
 
 # A vertical bar appears in the lower right region and text jumps to the left.
-.c it st -anchor n -relw .3 -relh .7 -relx .6 -rely .3 -bar red
+.c itemco st -anchor n -relw .3 -relh .7 -relx .6 -rely .3 -bar red
 update; after $delay
 
-# Finally an monstrous outline forces a single "Hello" and shrinks the bar.
-.c it st -width 6m
+# Paint the backgound.
+.c itemco st -fill yellow
 update; after $delay
 
+# Let's test stippling.
+.c itemco st -stipple gray25
+update; after $delay
+
+# Finally a monstrous outline forces a single "Hello" and shrinks the bar.
+.c itemco st -width 6m
+update; after $delay
+
+# Identify.
+puts $tksticker_version
+catch {.c cr sticker -version} rcsid
+puts $rcsid
+
 # In case you have sourced the script interactively and want to play around...
 if !$tcl_interactive exit
